pub struct Config {
inner: InnerConfig,
}Expand description
Tracing configuration section: outer config after cross-field defaults are applied.
This is a wrapper type that dereferences to the inner config type.
Fields
inner: InnerConfigImplementations
Sourceimpl Config
impl Config
Sourcepub fn use_color_stdout(&self) -> bool
pub fn use_color_stdout(&self) -> bool
Returns true if standard output should use color escapes.
Automatically checks if Zebra is running in a terminal.
Sourcepub fn use_color_stderr(&self) -> bool
pub fn use_color_stderr(&self) -> bool
Returns true if standard error should use color escapes.
Automatically checks if Zebra is running in a terminal.
Sourcepub fn use_color_stdout_and_stderr(&self) -> bool
pub fn use_color_stdout_and_stderr(&self) -> bool
Returns true if output that could go to standard output or standard error
should use color escapes. Automatically checks if Zebra is running in a terminal.