pub struct InnerConfig {
pub use_color: bool,
pub force_use_color: bool,
pub filter: Option<String>,
pub buffer_limit: usize,
pub endpoint_addr: Option<SocketAddr>,
pub flamegraph: Option<PathBuf>,
pub progress_bar: Option<ProgressConfig>,
pub log_file: Option<PathBuf>,
pub use_journald: bool,
pub opentelemetry_endpoint: Option<String>,
pub opentelemetry_service_name: Option<String>,
pub opentelemetry_sample_percent: Option<u8>,
}Expand description
Tracing configuration section: inner config used to deserialize and apply cross-field defaults.
Fields
use_color: boolWhether to use colored terminal output, if available.
Colored terminal output is automatically disabled if an output stream is connected to a file. (Or another non-terminal device.)
Defaults to true, which automatically enables colored output to
terminals.
force_use_color: boolWhether to force the use of colored terminal output, even if it’s not available.
Will force Zebra to use colored terminal output even if it does not detect that the output is a terminal that supports colors.
Defaults to false, which keeps the behavior of use_color.
filter: Option<String>The filter used for tracing events.
The filter is used to create a tracing-subscriber
EnvFilter,
and more details on the syntax can be found there or in the examples
below.
If no filter is specified (None), the filter is set to info if the
-v flag is given and warn if it is not given.
Examples
warn,zebrad=info,zebra_network=debug sets a global warn level, an
info level for the zebrad crate, and a debug level for the
zebra_network crate.
[block_verify{height=Some\(block::Height\(.*000\)\)}]=tracesets trace level for all events occurring in the context of a
block_verify span whose height field ends in 000, i.e., traces the
verification of every 1000th block.
buffer_limit: usizeThe buffer_limit size sets the number of log lines that can be queued by the tracing subscriber to be written to stdout before logs are dropped.
Defaults to 128,000 with a minimum of 100.
endpoint_addr: Option<SocketAddr>The address used for an ad-hoc RPC endpoint allowing dynamic control of the tracing filter.
Install Zebra using cargo install --features=filter-reload to enable this config.
If this is set to None, the endpoint is disabled.
flamegraph: Option<PathBuf>Controls whether to write a flamegraph of tracing spans.
Install Zebra using cargo install --features=flamegraph to enable this config.
If this is set to None, flamegraphs are disabled. Otherwise, it specifies an output file path, as described below.
This path is not used verbatim when writing out the flamegraph. This is because the flamegraph is written out as two parts. First the flamegraph is constantly persisted to the disk in a “folded” representation that records collapsed stack traces of the tracing spans that are active. Then, when the application is finished running the destructor will flush the flamegraph output to the folded file and then read that file and generate the final flamegraph from it as an SVG.
The need to create two files means that we will slightly manipulate the path given to us to create the two representations.
Security
If you are running Zebra with elevated permissions (“root”), create the directory for this file before running Zebra, and make sure the Zebra user account has exclusive access to that directory, and other users can’t modify its parent directories.
Example
Given flamegraph = "flamegraph" we will generate a flamegraph.svg and
a flamegraph.folded file in the current directory.
If you provide a path with an extension the extension will be ignored and
replaced with .folded and .svg for the respective files.
progress_bar: Option<ProgressConfig>Shows progress bars for block syncing, and mempool transactions, and peer networking. Also sends logs to the default log file path.
This config field is ignored unless the progress-bar feature is enabled.
log_file: Option<PathBuf>If set to a path, write the tracing logs to that path.
By default, logs are sent to the terminal standard output.
But if the progress_bar config is activated, logs are sent to the standard log file path:
- Linux:
$XDG_STATE_HOME/zebrad.logor$HOME/.local/state/zebrad.log - macOS:
$HOME/Library/Application Support/zebrad.log - Windows:
%LOCALAPPDATA%\zebrad.logorC:\Users\%USERNAME%\AppData\Local\zebrad.log
Security
If you are running Zebra with elevated permissions (“root”), create the directory for this file before running Zebra, and make sure the Zebra user account has exclusive access to that directory, and other users can’t modify its parent directories.
use_journald: boolThe use_journald flag sends tracing events to systemd-journald, on Linux distributions that use systemd.
Install Zebra using cargo install --features=journald to enable this config.
opentelemetry_endpoint: Option<String>OpenTelemetry OTLP endpoint URL for distributed tracing.
Install Zebra using cargo install --features=opentelemetry to enable this config.
When None (default), OpenTelemetry is completely disabled with zero runtime overhead.
When set, traces are exported via OTLP HTTP protocol.
Example: "http://localhost:4318"
Can also be set via OTEL_EXPORTER_OTLP_ENDPOINT environment variable (lower precedence).
opentelemetry_service_name: Option<String>Service name reported to OpenTelemetry collector.
Defaults to "zebra" if not specified.
Can also be set via OTEL_SERVICE_NAME environment variable.
opentelemetry_sample_percent: Option<u8>Trace sampling percentage between 0 and 100.
Controls what percentage of traces are exported:
100= 100% (all traces, default)10= 10% (recommended for high-traffic production)0= 0% (effectively disabled)
Lower values reduce network/collector overhead for busy nodes.
Note: This differs from the standard OTEL_TRACES_SAMPLER_ARG which uses
a ratio (0.0-1.0). Zebra uses percentage (0-100) for consistency with
other integer-based configuration options.