pub struct Tracing {
filter_handle: Option<Handle<EnvFilter, Formatter<DefaultFields, Format<Full>, NonBlocking>>>,
initial_filter: String,
flamegrapher: Option<Grapher>,
otel_provider: Option<SdkTracerProvider>,
_guard: Option<WorkerGuard>,
}Expand description
Abscissa component for initializing the tracing subsystem
Fields
filter_handle: Option<Handle<EnvFilter, Formatter<DefaultFields, Format<Full>, NonBlocking>>>The installed filter reloading handle, if enabled.
initial_filter: StringThe originally configured filter.
flamegrapher: Option<Grapher>The installed flame graph collector, if enabled.
otel_provider: Option<SdkTracerProvider>The OpenTelemetry tracer provider, if enabled.
_guard: Option<WorkerGuard>Drop guard for worker thread of non-blocking logger, responsible for flushing any remaining logs when the program terminates.
Implementations
Sourceimpl Tracing
impl Tracing
Sourcepub fn new(
network: &Network,
config: Config,
uses_intro: bool,
) -> Result<Self, FrameworkError>
pub fn new( network: &Network, config: Config, uses_intro: bool, ) -> Result<Self, FrameworkError>
Try to create a new Tracing component with the given config.
If uses_intro is true, show a welcome message, the network,
and the Zebra logo on startup. (If the terminal supports it.)
Sourcepub fn shutdown(&mut self)
pub fn shutdown(&mut self)
Drops guard for worker thread of non-blocking logger, to flush any remaining logs when the program terminates.
Sourcepub fn reload_filter(&self, filter: impl Into<EnvFilter>)
pub fn reload_filter(&self, filter: impl Into<EnvFilter>)
Reload the currently-active filter with the supplied value.
This can be used to provide a dynamic tracing filter endpoint.